from django.conf.urls.defaults import patterns, url
from django.core.urlresolvers import reverse
from django.utils.functional import lazy
from django.views.generic import FormView, TemplateView

from .views import PassengersFormView

reverse_lazy = lazy(reverse, str)

urlpatterns = patterns('',
    url(r'^$',
        PassengersFormView.as_view(success_url=reverse_lazy('orders_success')),
        name='orders_form'),
    url(r'^success/$',
        TemplateView.as_view(template_name='orders/success.html'),
        name='orders_success'),
)



from django import forms
from .widgets import FormSetWidget


class FormSetField(forms.Field):

    widget = FormSetWidget

    def __init__(self, formset_class, template=None, *args, **kwargs):
        self.formset_class = formset_class
        self.template = template or 'formsetfield/formsetfield.html'
        super(FormSetField, self).__init__(*args, **kwargs)

    def validate(self, value):
        if not value.is_valid():
            raise forms.ValidationError(self.error_messages['invalid'])

    def clean(self, value):
        return super(FormSetField, self).clean(value).cleaned_data

    def widget_attrs(self, widget):
        return {'formset_class': self.formset_class, 'template': self.template}



from django import forms
from django.forms.formsets import formset_factory

from formsetfield.fields import FormSetField


class AdultForm(forms.Form):

    fullname = forms.CharField()
    passport = forms.CharField()


class ChildForm(forms.Form):

    fullname = forms.CharField()
    birth_certificate = forms.CharField()


class PassengersForm(forms.Form):

    adults = FormSetField(formset_factory(AdultForm, extra=2))
    children = FormSetField(formset_factory(ChildForm, extra=2))



from django import forms
from django.template.loader import render_to_string
from django.utils.safestring import mark_safe


class FormSetWidget(forms.Widget):

    def render(self, name, value, attrs=None):
        if value is None:
            value = self.attrs['formset_class'](prefix=name)
        return render_to_string(self.attrs['template'], {'formset': value})

    def value_from_datadict(self, data, files, name):
        return self.attrs['formset_class'](data, files, prefix=name)



from django.views.generic import FormView
from .forms import PassengersForm


class PassengersFormView(FormView):

    form_class = PassengersForm
    template_name = 'orders/form.html'

    def form_valid(self, form):
        return self.render_to_response(self.get_context_data(form=form))
